package WebGUI::i18n::Spanish::Asset_EventManagementSystem;
use utf8;
our $I18N = {
  'Admin manage sub events large resultset' => {
    'lastUpdated' => '1216588605',
    'message' => 'Tu puedes manejar los eventos mostrados abajo. Debido a la gran cantidad de sub-eventos disponibles ninguno ser&aacute; mostrado, por favor limite los resultados usando las opciones de filtrado b&aacute;sicos o avanzados mostradas en la parte superior.'
  },
  'Admin manage sub events small resultset' => {
    'lastUpdated' => '1216588672',
    'message' => 'Puedes manejar los eventos mostrados abajo. Puedes limitar el listado de eventos usando las opciones de filtrado b&aacute;sicas o avanzadas mostradas en la parte superior.'
  },
  'Event Number' => {
    'lastUpdated' => '1219417958',
    'message' => 'Numero de evento'
  },
  'User sub events large resultset' => {
    'lastUpdated' => '1216588824',
    'message' => 'Puedes escojer los siguientes sub-eventos. Debido a la gran cantidad de sub-eventos disponibles, ninguno ser&aacute; mostrado, por favor, limite los resultados usando las opciones de filtrado mostradas en la parte superior.'
  },
  'User sub events small resultset' => {
    'lastUpdated' => '1221671247',
    'message' => 'Usted puede tambi&eacute;n seleccionar de los siguientes subeventos. Usted puede reducir la lista de subeventos usando las opciones de filtro b&aacute;sicas o avanzadas de arriba.'
  },
  'add a badge' => {
    'lastUpdated' => '1252515600',
    'message' => 'Agregar gafete'
  },
  'add a badge group' => {
    'lastUpdated' => '1252515609',
    'message' => 'Agregar un Grupo de Gafetes'
  },
  'add a ribbon' => {
    'lastUpdated' => '1252516172',
    'message' => 'Agregar una Banda'
  },
  'add a ticket' => {
    'lastUpdated' => '1252515642',
    'message' => 'Agregar una Entrada'
  },
  'add a token' => {
    'lastUpdated' => '1252515649',
    'message' => 'Agregar una Ficha'
  },
  'add an event meta field' => {
    'lastUpdated' => '1252515663',
    'message' => 'Agregar un Meta Campo al Evento'
  },
  'add more items' => {
    'lastUpdated' => '1252515677',
    'message' => 'Agregar Items'
  },
  'add submission' => {
    'lastUpdated' => '1259626833',
    'message' => 'Nuevo'
  },
  'add to badge' => {
    'lastUpdated' => '1252515686',
    'message' => 'Agregar a un Gafete'
  },
  'add to badge message' => {
    'lastUpdated' => '1252515701',
    'message' => '%s fue agregado con éxito al Gafete'
  },
  'add to cart' => {
    'lastUpdated' => '1252515711',
    'message' => 'Agregar al Carrito'
  },
  'add/edit approve event' => {
    'lastUpdated' => '1252515721',
    'message' => 'Aprobar Evento'
  },
  'add/edit event description' => {
    'lastUpdated' => '1252515730',
    'message' => 'Descripción'
  },
  'add/edit event description description' => {
    'lastUpdated' => '1252515748',
    'message' => 'Los detalles del Evento, tales como ubicación, hora y tema del Evento.'
  },
  'add/edit event end date' => {
    'lastUpdated' => '1252515761',
    'message' => 'Fin'
  },
  'add/edit event image' => {
    'lastUpdated' => '1252515768',
    'message' => 'Imagen del Evento'
  },
  'add/edit event image description' => {
    'lastUpdated' => '1252515787',
    'message' => 'Una imagen que representa el Evento para mostrarla a los visitantes del sitio.'
  },
  'add/edit event maximum attendees' => {
    'lastUpdated' => '1252515795',
    'message' => 'Descripción'
  },
  'add/edit event operator' => {
    'lastUpdated' => '1252515803',
    'message' => 'Operador'
  },
  'add/edit event operator description' => {
    'lastUpdated' => '1252515866',
    'message' => 'A medida que los Eventos Asoicados se agregan al Evento, puede especificar que todos los Eventos Asociados sean obligatorios o que basta con alguno de los Eventos.'
  },
  'add/edit event price description' => {
    'lastUpdated' => '1252515984',
    'message' => 'El costo para participar en el Evento.'
  },
  'add/edit event required events' => {
    'lastUpdated' => '1252515997',
    'message' => 'Eventos Requeridos'
  },
  'add/edit event required events description' => {
    'lastUpdated' => '1252516031',
    'message' => 'Puede indicar que el usuario esté en la obligación de registrarse en determinados Eventos antes de permitirle registrarse en este Evento.'
  },
  'add/edit event start date' => {
    'lastUpdated' => '1252516038',
    'message' => 'Inicio'
  },
  'add/edit event start date help' => {
    'lastUpdated' => '1252516057',
    'message' => 'La fecha y hora de inicio del Evento.'
  },
  'add/edit event template' => {
    'lastUpdated' => '1252516074',
    'message' => 'Plantilla para Evento'
  },
  'add/edit event title' => {
    'lastUpdated' => '1252516082',
    'message' => 'Título del Evento'
  },
  'add/edit event title description' => {
    'lastUpdated' => '1252516095',
    'message' => 'Escriba el nombre o título de su Evento.'
  },
  'add/edit useSalesTax' => {
    'lastUpdated' => '1252516111',
    'message' => '¿Aplicar Impuesto a las Ventas?'
  },
  'add/edit useSalesTax description' => {
    'lastUpdated' => '1252516126',
    'message' => '¿Debe aplicarse el Impuesto a las Ventas sobre el costo del Evento?'
  },
  'addBadgeUrl' => {
    'lastUpdated' => '1252516139',
    'message' => 'URL para agregar un Gafete al sistema.'
  },
  'addRibbonUrl' => {
    'lastUpdated' => '1252516183',
    'message' => 'URL para agregar una Banda a un Gafete.'
  },
  'addTicketUrl' => {
    'lastUpdated' => '1252516199',
    'message' => 'URL para agregar una Entrada a un Gafete.'
  },
  'addTokenUrl' => {
    'lastUpdated' => '1252516210',
    'message' => 'URL para agregar una Ficha a un Gafete.'
  },
  'address' => {
    'lastUpdated' => '1252516217',
    'message' => 'Dirección'
  },
  'address1' => {
    'lastUpdated' => '1252516248',
    'message' => 'Dirección en el Gafete del Usuario (Línea 1)'
  },
  'address2' => {
    'lastUpdated' => '1252516258',
    'message' => 'Dirección en el Gafete del Usuario (Línea 2)'
  },
  'address3' => {
    'lastUpdated' => '1252516266',
    'message' => 'Dirección en el Gafete del Usuario (Línea 3)'
  },
  'addressBook' => {
    'lastUpdated' => '1252516286',
    'message' => 'Un botón para buscar direcciones de la Libreta de Direcciones del usuario.'
  },
  'allowed sub events' => {
    'lastUpdated' => '1252516316',
    'message' => 'Ud. puede asistir a los Sub Eventos indicados según los Eventos actualmente en su Carrito.'
  },
  'approved' => {
    'lastUpdated' => '1259453618',
    'message' => 'Aprobado'
  },
  'assetId' => {
    'lastUpdated' => '1257424102',
    'message' => 'El AssetID de esta Entrada'
  },
  'assetName' => {
    'lastUpdated' => '1216072854',
    'message' => 'Administrador de Eventos'
  },
  'assetSize' => {
    'lastUpdated' => '1257424117',
    'message' => 'El tamaño de este Activo Entrada'
  },
  'badge builder template' => {
    'lastUpdated' => '1252516327',
    'message' => 'Plantilla para Crear Gafete'
  },
  'badge builder template help' => {
    'lastUpdated' => '1252516344',
    'message' => 'Seleccione la Plantilla a utilizar para la creación de Gafetes.'
  },
  'badge group name' => {
    'lastUpdated' => '1252518701',
    'message' => 'Nombre del Grupo de Gafetes'
  },
  'badge group name help' => {
    'lastUpdated' => '1252518734',
    'message' => 'Este nombre será utilizado para referirse en conjunto a todos los Gafetes de este grupo.'
  },
  'badge group ticketsPerBadge' => {
    'lastUpdated' => '1317823367',
    'message' => 'Tickets por Gafete'
  },
  'badge group ticketsPerBadge help' => {
    'lastUpdated' => '1317823398',
    'message' => 'El número de Tickets que puede comprar cada Gafete en este grupo.'
  },
  'badge groups' => {
    'lastUpdated' => '1252518745',
    'message' => 'Grupos de Gafetes'
  },
  'badge holder information' => {
    'lastUpdated' => '1252518778',
    'message' => 'Información del Participante'
  },
  'badge id' => {
    'lastUpdated' => '1252518801',
    'message' => 'ID del Gafete'
  },
  'badge instructions' => {
    'lastUpdated' => '1252518810',
    'message' => 'Instrucciones del Gafete'
  },
  'badge instructions help' => {
    'lastUpdated' => '1252518830',
    'message' => 'Instrucciones para el usuario en cuanto al uso del Gafete.'
  },
  'badge number' => {
    'lastUpdated' => '1252518841',
    'message' => 'Gafete #'
  },
  'badgeAssetId' => {
    'lastUpdated' => '1252518859',
    'message' => 'El <strong>assetID</strong> del Gafete.'
  },
  'badgeBuilderTemplateId help' => {
    'lastUpdated' => '1252518884',
    'message' => 'El ID de la Plantilla para la pantalla de Creación de Gafetes.'
  },
  'badgeId' => {
    'lastUpdated' => '1252518908',
    'message' => 'El ID del Gafete del usuario actual.'
  },
  'badgeInstructions help' => {
    'lastUpdated' => '1252518923',
    'message' => 'Instrucciones para el usuario en cuanto al uso del Gafete.'
  },
  'badgeLabel' => {
    'lastUpdated' => '1252518948',
    'message' => 'Mi Gafete'
  },
  'badgeNumber' => {
    'lastUpdated' => '1252518959',
    'message' => 'El número de este Gafete.'
  },
  'badgeTitle' => {
    'lastUpdated' => '1252518977',
    'message' => 'El Título del Gafete a imprimir.'
  },
  'badgeUrl' => {
    'lastUpdated' => '1252518993',
    'message' => 'El URL para agregar otro Gafete en el Carrito del usuario.'
  },
  'buildBadgeUrl' => {
    'lastUpdated' => '1252519019',
    'message' => 'URL hacia la información relativa al Gafete actual.'
  },
  'buy' => {
    'lastUpdated' => '1216072861',
    'message' => 'Comprar'
  },
  'buy badge' => {
    'lastUpdated' => '1252519030',
    'message' => 'Comprar Gafete'
  },
  'buyBadgeUrl' => {
    'lastUpdated' => '1252519039',
    'message' => 'URL para comprar un Gafete.'
  },
  'canEdit' => {
    'lastUpdated' => '1252519061',
    'message' => 'Un condicional que indica si el usuario actual puede o no editar el Sistema de Manejo de Eventos.'
  },
  'canReturnTransaction' => {
    'lastUpdated' => '1252519074',
    'message' => 'Un condicional que indica si las compras pueden ser devueltas.'
  },
  'cancel registration' => {
    'lastUpdated' => '1252519085',
    'message' => 'Cancelar Registro'
  },
  'check required fields' => {
    'lastUpdated' => '1252519104',
    'message' => 'Debe completar los siguientes campos obligatorios:'
  },
  'checked in' => {
    'lastUpdated' => '1252519126',
    'message' => 'Se registró'
  },
  'checkout' => {
    'lastUpdated' => '1252519141',
    'message' => 'Salió'
  },
  'choose a file to import' => {
    'lastUpdated' => '1217241814',
    'message' => 'Elija un archivo para importarlo'
  },
  'city' => {
    'lastUpdated' => '1221579423',
    'message' => 'Ciudad'
  },
  'clear form' => {
    'lastUpdated' => '1317823406',
    'message' => 'Limpiar'
  },
  'confirm delete event metadata' => {
    'lastUpdated' => '1252519173',
    'message' => '¿Está seguro de querer eliminar este campo de meta datos? Los valores asociados a este campo de meta datos serán eliminados de <strong>todos</strong> los Eventos.'
  },
  'country' => {
    'lastUpdated' => '1252519183',
    'message' => 'País'
  },
  'create a badge for myself' => {
    'lastUpdated' => '1252519194',
    'message' => 'Crear un Gafete para mí'
  },
  'create a badge for someone else' => {
    'lastUpdated' => '1252519206',
    'message' => 'Crear un Gafete para otra persona'
  },
  'created' => {
    'lastUpdated' => '1259453629',
    'message' => 'Creado'
  },
  'creationDate' => {
    'lastUpdated' => '1257424135',
    'message' => 'Fecha de creación de este Activo como una época Unix.'
  },
  'customRequestUrl' => {
    'lastUpdated' => '1252519228',
    'message' => 'Un URL hacia el YUI para buscar información acerca del Gafete actual.'
  },
  'default badge instructions' => {
    'lastUpdated' => '1252519269',
    'message' => 'Ud. necesita un Gafete para asistir a este evento. Seleccione el tipo de Gafete que se adapte a sus necesidades y presupuesto.'
  },
  'default ribbon instructions' => {
    'lastUpdated' => '1252519334',
    'message' => 'Las Bandas le otorgan descuentos sobre un grupo de Eventos relacionados. Puede agregar una o más Bandas a su Gafete para obtener los descuentos.'
  },
  'default submitted location list' => {
    'lastUpdated' => '1259626851',
    'message' => ' '
  },
  'default ticket instructions' => {
    'lastUpdated' => '1252519402',
    'message' => 'Las Entradas le permiten reservar un asiento en las sesiones que tienen lugar durante el Evento. Agregue Entradas a su Gafete para aquellas sesiones a las cuales planea asistir.'
  },
  'default token instructions' => {
    'lastUpdated' => '1252519439',
    'message' => 'Las Fichas son la unidad monetaria del Evento. Le permiten comprar Eventos y otros materiales sin necesidad de comprar una Entrada específica.'
  },
  'delete' => {
    'lastUpdated' => '1252519448',
    'message' => 'Eliminar'
  },
  'denied' => {
    'lastUpdated' => '1259453647',
    'message' => 'Negado'
  },
  'duration' => {
    'lastUpdated' => '1252519454',
    'message' => 'Duración'
  },
  'duration help' => {
    'lastUpdated' => '1252519467',
    'message' => '¿Cuánto dura este Evento?'
  },
  'early bird price' => {
    'lastUpdated' => '1252519559',
    'message' => 'Precio de Registro Anticipado'
  },
  'early bird price end date' => {
    'lastUpdated' => '1252519574',
    'message' => 'Fin de Registros Anticipados'
  },
  'early bird price end date help' => {
    'lastUpdated' => '1252519517',
    'message' => 'La fecha a partir de la cual registrarse tiene el costo total.'
  },
  'early bird price help' => {
    'lastUpdated' => '1252519540',
    'message' => 'El precio especial para este Gafete si el usuario se registra con anticipación.'
  },
  'edit' => {
    'lastUpdated' => '1216072867',
    'message' => 'Editar'
  },
  'edit submission form' => {
    'lastUpdated' => '1259626866',
    'message' => 'Editar Formulario de Propuestas'
  },
  'email' => {
    'lastUpdated' => '1252519596',
    'message' => 'La dirección de correo del usuario en el Gafete.'
  },
  'email address' => {
    'lastUpdated' => '1252519611',
    'message' => 'Correo Electrónico'
  },
  'ems asset template variables' => {
    'lastUpdated' => '1252519628',
    'message' => 'Sistema de Manejo de Eventos, Variables de Plantilla'
  },
  'ems badge' => {
    'lastUpdated' => '1252519647',
    'message' => 'Gafete para Eventos'
  },
  'ems ribbon' => {
    'lastUpdated' => '1252519654',
    'message' => 'Cinta para Eventos'
  },
  'ems ticket' => {
    'lastUpdated' => '1252519664',
    'message' => 'Entrada para Eventos'
  },
  'ems token' => {
    'lastUpdated' => '1252519672',
    'message' => 'Ficha para Eventos'
  },
  'ems view badge address1' => {
    'lastUpdated' => '1252519715',
    'message' => 'Primer campo para la dirección en la Plantilla de Ver Gafete.'
  },
  'ems view badge address2' => {
    'lastUpdated' => '1252519724',
    'message' => 'Segundo campo para la dirección en la Plantilla de Ver Gafete.'
  },
  'ems view badge address3' => {
    'lastUpdated' => '1252519734',
    'message' => 'Tercer campo para la dirección en la Plantilla de Ver Gafete.'
  },
  'ems view badge city' => {
    'lastUpdated' => '1252519746',
    'message' => 'Campo para la ciudad en la Plantilla de Ver Gafete.'
  },
  'ems view badge country' => {
    'lastUpdated' => '1252519763',
    'message' => 'Campo para el país en la Plantilla de Ver Gafete.'
  },
  'ems view badge description' => {
    'lastUpdated' => '1252519786',
    'message' => 'Campo para la descripción del Gafete en la Plantilla de Ver Gafete.'
  },
  'ems view badge email' => {
    'lastUpdated' => '1252519796',
    'message' => 'Campo para el correo electrónico en la Plantilla de Ver Gafete.'
  },
  'ems view badge error' => {
    'lastUpdated' => '1252519822',
    'message' => 'Errores ocurridos mientras se intentaba agregar el Gafete al Carrito del usuario.'
  },
  'ems view badge name' => {
    'lastUpdated' => '1252519841',
    'message' => 'Campo para el nombre del usuario en la Plantilla de Ver Gafete.'
  },
  'ems view badge organization' => {
    'lastUpdated' => '1252519857',
    'message' => 'Campo para la organización del usuario en la Plantilla de Ver Gafete.'
  },
  'ems view badge phone' => {
    'lastUpdated' => '1252519868',
    'message' => 'Campo para el teléfono en la Plantilla de Ver Gafete.'
  },
  'ems view badge state' => {
    'lastUpdated' => '1252519878',
    'message' => 'Campo para el estado o provincia en la Plantilla de Ver Gafete.'
  },
  'ems view badge submitAddress' => {
    'lastUpdated' => '1252519892',
    'message' => 'Botón para enviar los datos de la dirección.'
  },
  'ems view badge title' => {
    'lastUpdated' => '1252519907',
    'message' => 'Campo para el título en la Plantilla de Ver Gafete.'
  },
  'ems view badge zipcode' => {
    'lastUpdated' => '1252519918',
    'message' => 'Campo para el código postal en la Plantilla de Ver Gafete.'
  },
  'emsAssetId' => {
    'lastUpdated' => '1252519942',
    'message' => 'El <strong>assetID</strong> del Sistema de Manejo de Eventos que contiene el Gafete.'
  },
  'encryptPage' => {
    'lastUpdated' => '1257424158',
    'message' => 'Indica si se debe cifrar o no la página en la cual se despliega la Entrada.'
  },
  'enter import file' => {
    'lastUpdated' => '1252519957',
    'message' => 'Indique el archivo a importar'
  },
  'error' => {
    'lastUpdated' => '1252519969',
    'message' => 'Error:'
  },
  'error badge group ticket limit' => {
    'lastUpdated' => '1317823426',
    'message' => 'Imposible agregar %s pues se excedió el límite de Tickets.'
  },
  'error no colon' => {
    'lastUpdated' => '1252519979',
    'message' => 'Error'
  },
  'event number' => {
    'lastUpdated' => '1252519987',
    'message' => 'Evento #'
  },
  'event number help' => {
    'lastUpdated' => '1252520020',
    'message' => 'Un número que representa el Evento, que sirve de referencia para usarlo en Catálogos de Eventos.'
  },
  'event start date' => {
    'lastUpdated' => '1252520031',
    'message' => 'Inicia el'
  },
  'event submission main template' => {
    'lastUpdated' => '1259627004',
    'message' => 'Plantilla Principal para Propuesta de Evento'
  },
  'event submission main template help' => {
    'lastUpdated' => '1259626937',
    'message' => 'Indique la plantilla a emplear para desplegar el formulario principal para Propuesta de Eventos. Tiene un conjunto dinámico de pestañas, que se usa para contener uno o más elementos de la interfaz.'
  },
  'event submission queue template' => {
    'lastUpdated' => '1259626954',
    'message' => 'Plantilla para Cola de Propuestas de Eventos'
  },
  'event submission queue template help' => {
    'lastUpdated' => '1259626983',
    'message' => 'Indique la plantilla a emplear para presentar la Cola de Propuestas de Eventos, tanto para los proponentes como para los administradores.'
  },
  'event submission template' => {
    'lastUpdated' => '1259626996',
    'message' => 'Plantilla para Propuestas'
  },
  'event submission template help' => {
    'lastUpdated' => '1259627061',
    'message' => 'Indique la plantilla a emplear para una Propuesta de Evento. Casi todo su contenido se compone con el formulario principal según la descripción indicada por el administrador.'
  },
  'event template help title' => {
    'lastUpdated' => '1252520045',
    'message' => 'Plantilla de Evento'
  },
  'eventMetaData' => {
    'lastUpdated' => '1257424177',
    'message' => 'Meta datos para el Evento provistos como una estructura de datos JSON.'
  },
  'expire ems cart items' => {
    'lastUpdated' => '1252520070',
    'message' => 'Expirar Items de Eventos en Carritos'
  },
  'export' => {
    'lastUpdated' => '1252520077',
    'message' => 'Exportar'
  },
  'export error' => {
    'lastUpdated' => '1252520094',
    'message' => 'Ocurrió un error al exportar.'
  },
  'export events' => {
    'lastUpdated' => '1252520101',
    'message' => 'Exportar Eventos'
  },
  'exportTicketsUrl' => {
    'lastUpdated' => '1252520115',
    'message' => 'El URL para exportar Entradas. No está implantado todavía.'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1257424224',
    'message' => 'Marcas HTML adicionales que deben ser incluídas en el encabezado de presentación de esta Entrada.'
  },
  'extraHeadTagsPacked' => {
    'lastUpdated' => '1257424244',
    'message' => 'Marcas HTML adicionales que deben ser incluídas en el encabezado de presentación de esta Entrada, reduciendo los espacios en blanco a su mínima expresión.'
  },
  'failed' => {
    'lastUpdated' => '1259627071',
    'message' => 'Fallido'
  },
  'feedback' => {
    'lastUpdated' => '1259627078',
    'message' => 'Feedback'
  },
  'field count mismatch' => {
    'lastUpdated' => '1252520139',
    'message' => 'El registro %d tiene %d campos, en lugar de los %d indicados por los checkboxes marcados.'
  },
  'filter' => {
    'lastUpdated' => '1252520147',
    'message' => 'Filtrar'
  },
  'first name' => {
    'lastUpdated' => '1216072880',
    'message' => 'Primer Nombre'
  },
  'forced narrowing' => {
    'lastUpdated' => '1252520190',
    'message' => 'Debido a la gran cantidad de requisitos previos no se mostrará ninguno, por favor refine su búsqueda utilizando filtros.'
  },
  'formFooter' => {
    'lastUpdated' => '1252520210',
    'message' => 'Código HTML para terminar la Plantilla de Mostrar Gafete.'
  },
  'formHeader' => {
    'lastUpdated' => '1252520223',
    'message' => 'Código HTML para comenzar la Plantilla de Mostrar Gafete.'
  },
  'getBadgesUrl' => {
    'lastUpdated' => '1252520250',
    'message' => 'URL para obtener la información del Gafete en forma de JSON para la base de datos YUI.'
  },
  'getRegistrantsUrl' => {
    'lastUpdated' => '1252520270',
    'message' => 'URL para obtener la información de registro en formato JSON.'
  },
  'getRibbonsUrl' => {
    'lastUpdated' => '1252520286',
    'message' => 'URL para obtener información de Cintas en formato JSON.'
  },
  'getTicketsUrl' => {
    'lastUpdated' => '1252520300',
    'message' => 'URL para obtener información de Entradas en formato JSON.'
  },
  'getTokensUrl' => {
    'lastUpdated' => '1252520313',
    'message' => 'URL para obtener información de Fichas en formato JSON.'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1257424256',
    'message' => 'El ID del Grupo que puede Editar esta Entrada.'
  },
  'groupIdView' => {
    'lastUpdated' => '1257424271',
    'message' => 'El ID del Grupo que puede mirar esta Entrada.'
  },
  'hasBadge' => {
    'lastUpdated' => '1252520328',
    'message' => 'Un condicional que indica si el usuario actual tiene un Gafete o no.'
  },
  'hasCheckedIn' => {
    'lastUpdated' => '1252520348',
    'message' => 'Un condicional que indica si el usuario se ha registrado en el Evento o no.'
  },
  'help badgeMeta' => {
    'lastUpdated' => '1317823468',
    'message' => 'Agregar un valor de metadatos a la Plantilla indicando su nombre después del prefijo "badgeMeta_", e.g. badgeMeta_departamento'
  },
  'help ticketMeta' => {
    'lastUpdated' => '1317823507',
    'message' => 'Agregar valores de metadatos a la Plantilla usando su nombre después del prefijo "ticketMeta_", e.g. ticketMeta_departamento'
  },
  'hours' => {
    'lastUpdated' => '1216073286',
    'message' => 'Horas'
  },
  'ignore first line' => {
    'lastUpdated' => '1252520359',
    'message' => '¿Ignorar primera línea?'
  },
  'image' => {
    'lastUpdated' => '1252520372',
    'message' => 'La imagen asignada para representar este Evento.'
  },
  'import' => {
    'lastUpdated' => '1216072889',
    'message' => 'Importar'
  },
  'import blank line' => {
    'lastUpdated' => '1252520389',
    'message' => 'El registro %d estaba en blanco y fue ignorado.'
  },
  'import events' => {
    'lastUpdated' => '1252520397',
    'message' => 'Importar Eventos'
  },
  'import field is duplicate key description' => {
    'lastUpdated' => '1252520551',
    'message' => 'Para manejar los Eventos duplicados de manera inteligente, el sistema necesita poder identificar un registro como duplicado. Marcando los checkboxes Ud. le indica al sistema cuales campos necesita considerar cuando trate de encontrar un registro existente para el evento que se está tratando de importar. Por ejemplo, si marca Título del Evento y Fecha de Inicio del Evento como los únicos campos clave, entonces si el Título del Evento y Fecha de Inicio del Evento del registro a importar coinciden con el de algún evento existente, el registro se considera duplicado. En ese caso, el sistema ignorará el nuevo registro o sobreescribirá el existente con los nuevos datos.'
  },
  'import field is duplicate key title' => {
    'lastUpdated' => '1252520571',
    'message' => 'Campo Clave'
  },
  'import file contains field description' => {
    'lastUpdated' => '1252520621',
    'message' => 'Marque los checkboxes correspondientes a los campos que están incluidos en el archivo a importar. Note que los campos deben estar en el orden mostrado, y que todos los campos obligatorios deben haber sido marcados y contener datos en el archivo para poder procesarlos.'
  },
  'import file contains field title' => {
    'lastUpdated' => '1252520635',
    'message' => 'Archivo Contiene el Campo'
  },
  'import form header' => {
    'lastUpdated' => '1252520670',
    'message' => 'Con este formulario Ud. puede importar datos directamente al Sistema de Manejo de Eventos. Asegúrese que los campos especificados están en el orden mostrado más abajo.'
  },
  'import hoverhelp dups' => {
    'lastUpdated' => '1252520751',
    'message' => 'El sistema utilizarla los campos que Ud. especifique debajo de \'Campo Clave\' para identificar registros duplicados. Cuando se detecte un evento duplicado, este campo determinará que hacer con el registro duplicarlo: ignorarlo o sobreescribir el existente con los datos nuevos. Note que todos los campos se sobreescriben, independientemente de que estén presentes o no en el nuevo registro.'
  },
  'import hoverhelp file' => {
    'lastUpdated' => '1252520954',
    'message' => 'Importe un archivo de valores separados por comas para agregar Eventos. Los campos deben estar delimitados con comas, usando comillas dobles (") para encerrar aquellos campos que contienen comas en su valor. Si los valores incluyen comillas dobles, estas deben escaparse usando dos comillas dobles seguidas (""). Se verificará la cantidad de campos especificados así como la presencia de los campos obligatorios antes de importarlos. La verificación no incluye determinar la validez de LDAP, enlaces a bases de datos o Plantillas. Los campos que llevan múltiples valores deben combinarse en un sólo campo CSV utilizando punto y coma (;) como conector.'
  },
  'import hoverhelp first line' => {
    'lastUpdated' => '1252520989',
    'message' => 'Si la primera línea de su archivo a importar contiene los nombres de los campos en lugar de valores para un registro de Eventos, indique \'Si\' para ignorarla.'
  },
  'import invalid prereq' => {
    'lastUpdated' => '1252521021',
    'message' => 'El registro %d tiene un Requisito Previo inválido (%s). Necesita crear los Requisitos Previos antes de importar.'
  },
  'import invalid status' => {
    'lastUpdated' => '1252521055',
    'message' => 'El registro %d tiene un Estado inválido (%s). Los valores válidos son: Aprobado, Cancelado, Rechazado o Pendiente.'
  },
  'import invalid template' => {
    'lastUpdated' => '1252521089',
    'message' => 'El registro %d tiene un Nombre de Plantilla inválido (%s). Necesita crear la Plantilla de Evento relevante antes de importar los datos.'
  },
  'import line parse error' => {
    'lastUpdated' => '1252524018',
    'message' => 'Ocurrió un error al procesar la entrada \'%s\' en la línea %d.'
  },
  'import missing required' => {
    'lastUpdated' => '1252524068',
    'message' => 'El registro %d no incluye valor para el campo %s que es obligatorio.'
  },
  'import need dup key' => {
    'lastUpdated' => '1252524128',
    'message' => 'Debe seleccionar al menos un campo clave para detección de duplicados.'
  },
  'import ok' => {
    'lastUpdated' => '1252524404',
    'message' => 'Se procesaron %d registros: %d creados, %d líneas en blanco, %d duplicados %s.'
  },
  'import other line' => {
    'lastUpdated' => '1252524419',
    'message' => 'Registro %d fue %s.'
  },
  'import record parse error' => {
    'lastUpdated' => '1252524445',
    'message' => 'Ocurrió un error al procesar el registro %d: \'%s\'.'
  },
  'importTicketsUrl' => {
    'lastUpdated' => '1252524521',
    'message' => 'URL para importar Entradas. No está implantado todavía.'
  },
  'inheritUrlFromParent' => {
    'lastUpdated' => '1257424288',
    'message' => 'Indica si se debe heredar el URL del padre o no.'
  },
  'is required' => {
    'lastUpdated' => '1216073871',
    'message' => '%s es obligatorio.'
  },
  'isExportable' => {
    'lastUpdated' => '1257424301',
    'message' => 'Indica si la Entrada puede ser exportada.'
  },
  'isHidden' => {
    'lastUpdated' => '1257424317',
    'message' => 'Indica si la Entrada debe ocultarse para que no aparezca en el menú.'
  },
  'isPackage' => {
    'lastUpdated' => '1257424329',
    'message' => 'Indica si este Activo es un Paquete o no.'
  },
  'isPrototype' => {
    'lastUpdated' => '1257424342',
    'message' => 'Indica si este Activo Entrada es un Prototipo.'
  },
  'isRegistrationStaff' => {
    'lastUpdated' => '1252524560',
    'message' => 'Un condicional que indica si el usuario actual forma parte o no del grupo de Staff de Registro del Sistema de Eventos.'
  },
  'item expiration time' => {
    'lastUpdated' => '1252524678',
    'message' => 'Fecha de Expiración del Item'
  },
  'item expiration time help' => {
    'lastUpdated' => '1252524749',
    'message' => '¿Cuánto tiempo pueden estar los items del Sistema de Eventos en el Carrito antes de que sean expirados para que otro usuario los pueda comprar?'
  },
  'label' => {
    'lastUpdated' => '1216072897',
    'message' => 'Etiqueta'
  },
  'label help' => {
    'lastUpdated' => '1252525101',
    'message' => 'La etiqueta para el campo que el usuario debe leer para saber el uso del campo.'
  },
  'last name' => {
    'lastUpdated' => '1216073219',
    'message' => 'Apellido'
  },
  'lastModified' => {
    'lastUpdated' => '1257424357',
    'message' => 'Fecha de última modificación de este Ticket, como época Unix.'
  },
  'location' => {
    'lastUpdated' => '1216072920',
    'message' => 'Ubicaci&oacute;n'
  },
  'location help' => {
    'lastUpdated' => '1252525126',
    'message' => '¿En cuál sala o ubicación se llevará a cabo el Evento?'
  },
  'lookup badge' => {
    'lastUpdated' => '1252525183',
    'message' => 'Buscar un Gafete'
  },
  'lookup registrant template' => {
    'lastUpdated' => '1252525217',
    'message' => 'Plantilla para Buscar Inscritos'
  },
  'lookup registrant template help' => {
    'lastUpdated' => '1252525488',
    'message' => '¿Cuál Plantilla utilizar para desplegar la pantalla de búsqueda de inscritos en el Evento?'
  },
  'lookupRegistrantTemplateId help' => {
    'lastUpdated' => '1252525977',
    'message' => 'El ID de la Plantilla para la pantalla de búsqueda de inscritos en el Evento.'
  },
  'lookupRegistrantUrl' => {
    'lastUpdated' => '1252526010',
    'message' => 'URL para obtener información acerca de los Gafetes del usuario actual, o para todos los usuarios si el usuario actual forma parte del staff de registro del Evento.'
  },
  'main template' => {
    'lastUpdated' => '1252526095',
    'message' => 'Plantilla Principal'
  },
  'main template help' => {
    'lastUpdated' => '1252526209',
    'message' => 'Seleccione la Plantilla para la página principal que muestra los Gafetes disponibles a la venta.'
  },
  'main template help body' => {
    'lastUpdated' => '1252526247',
    'message' => 'Esta Plantilla usa YUI para hacer todo el trabajo de presentación. Solamente debe cambiarse la hoja de estilo CSS para lograr los cambios de apariencia.'
  },
  'main template help title' => {
    'lastUpdated' => '1252526455',
    'message' => 'Plantilla Principal Sistema Manejo de Eventos'
  },
  'manage' => {
    'lastUpdated' => '1252526479',
    'message' => 'Gestionar'
  },
  'manage discount passes' => {
    'lastUpdated' => '1252526531',
    'message' => 'Gestión de Pases de Descuento'
  },
  'manage event metadata' => {
    'lastUpdated' => '1252526586',
    'message' => 'Gestión de Metadatos del Evento'
  },
  'manage events' => {
    'lastUpdated' => '1252526646',
    'message' => 'Gestión de Eventos'
  },
  'manage prerequisite sets' => {
    'lastUpdated' => '1252526677',
    'message' => 'Gestión de Conjuntos de Requisitos Previos'
  },
  'manage prerequisites' => {
    'lastUpdated' => '1252526696',
    'message' => 'Gestión de Requisitos Previos'
  },
  'manage purchases' => {
    'lastUpdated' => '1252526709',
    'message' => 'Gestión de Compras'
  },
  'manageBadgeGroupsUrl' => {
    'lastUpdated' => '1252526744',
    'message' => 'URL para mostrar la lista de grupos de Gafetes.'
  },
  'manageEventMetaFieldsUrl' => {
    'lastUpdated' => '1252526767',
    'message' => 'URL a la pantalla de meta datos del Sistema de Manejo de Eventos'
  },
  'managePrereqsMessage' => {
    'lastUpdated' => '1252526790',
    'message' => 'Use el siguiente formulario para agregar requisitos previos a %s.'
  },
  'mark as checked in' => {
    'lastUpdated' => '1252527087',
    'message' => 'Marcar como Inscrito'
  },
  'mark as not checked in' => {
    'lastUpdated' => '1252527200',
    'message' => 'Marcar como no inscrito'
  },
  'menuTitle' => {
    'lastUpdated' => '1257424382',
    'message' => 'El título a ser usado en menús para esta Entrada.'
  },
  'meta field help text' => {
    'lastUpdated' => '1259627088',
    'message' => 'Texto de Ayuda'
  },
  'meta field help text description' => {
    'lastUpdated' => '1259627110',
    'message' => 'El texto de ayuda incluido en la interfaz de Propuesta de Evento.'
  },
  'meta fields' => {
    'lastUpdated' => '1252527299',
    'message' => 'Campos Meta'
  },
  'meta hover help' => {
    'lastUpdated' => '1252527319',
    'message' => 'Este es un campo personalizable. Consulte al administrador sobre su uso.'
  },
  'missing prerequisites message' => {
    'lastUpdated' => '1252527362',
    'message' => 'Algunos de los Eventos que ha seleccionado requieren asistir a otros Eventos previos. Cumpla con los requisitos de la siguiente lista antes de continuar.'
  },
  'my submissions' => {
    'lastUpdated' => '1259627117',
    'message' => 'Mis Propuestas'
  },
  'name' => {
    'lastUpdated' => '1252527424',
    'message' => 'Nombre del usuario del Gafete.'
  },
  'new form' => {
    'lastUpdated' => '1259627126',
    'message' => 'Nuevo Formulario'
  },
  'new submission' => {
    'lastUpdated' => '1259627135',
    'message' => 'Proponer Evento'
  },
  'new submission form' => {
    'lastUpdated' => '1259627148',
    'message' => 'Gestión de Propuestas'
  },
  'newWindow' => {
    'lastUpdated' => '1257424396',
    'message' => 'Indica si la Entrada debe ser desplegada en una nueva ventana.'
  },
  'next submission id label' => {
    'lastUpdated' => '1259627170',
    'message' => 'Siguiente Id de Propuesta'
  },
  'next submission id label help' => {
    'lastUpdated' => '1259627191',
    'message' => 'Este es el valor que será utilizado para completar la primera Propuesta. No lo modifique.'
  },
  'no' => {
    'lastUpdated' => '1252527548',
    'message' => 'no'
  },
  'no import took place' => {
    'lastUpdated' => '1252527571',
    'message' => 'No se pudo importar ningún registro. Hubo errores en la entrada:'
  },
  'no more available' => {
    'lastUpdated' => '1252527708',
    'message' => 'Error: no hay items disponibles para comprar.'
  },
  'not checked in' => {
    'lastUpdated' => '1252527723',
    'message' => 'No está inscrito'
  },
  'notes' => {
    'lastUpdated' => '1216072959',
    'message' => 'Notas'
  },
  'null field error' => {
    'lastUpdated' => '1252527735',
    'message' => 'El campo %s no puede estar vacío.'
  },
  'null field error recnum' => {
    'lastUpdated' => '1252527784',
    'message' => 'El campo %s no puede estar en blanco (registro %d).'
  },
  'option to narrow' => {
    'lastUpdated' => '1252527812',
    'message' => 'Puede refinar la lista de requisitos previos empleando las opciones de filtro básico y avanzado.'
  },
  'organization' => {
    'lastUpdated' => '1252527821',
    'message' => 'Organización'
  },
  'otherBadgesInCart' => {
    'lastUpdated' => '1252527842',
    'message' => 'Un ciclo que contiene enlaces y etiquetas para otros Gafetes en el Carrito del usuario.'
  },
  'overwrite' => {
    'lastUpdated' => '1252527858',
    'message' => 'Reemplazar'
  },
  'overwritten' => {
    'lastUpdated' => '1252527868',
    'message' => 'reemplazados'
  },
  'ownerUserId' => {
    'lastUpdated' => '1257424407',
    'message' => 'El UserID del propietario de esta Entrada.'
  },
  'pending' => {
    'lastUpdated' => '1259627197',
    'message' => 'Pendiente'
  },
  'percentage discount' => {
    'lastUpdated' => '1252527878',
    'message' => 'Porcentaje de Descuento'
  },
  'percentage discount help' => {
    'lastUpdated' => '1252527902',
    'message' => '¿Que porcentaje de descuente se aplicará a las Entradas si el usuario compra está Cinta?'
  },
  'phone number' => {
    'lastUpdated' => '1252528034',
    'message' => 'Teléfono'
  },
  'phoneNumber' => {
    'lastUpdated' => '1252528062',
    'message' => 'El número de telefóno para el Gafete del usuario.'
  },
  'populate from address book' => {
    'lastUpdated' => '1252528116',
    'message' => 'Alimentar desde Libreta de Direcciones'
  },
  'pre registration price' => {
    'lastUpdated' => '1252528155',
    'message' => 'Precio de Registro Anticipado'
  },
  'pre registration price end date' => {
    'lastUpdated' => '1252528172',
    'message' => 'Fecha límite para Registro Anticipado'
  },
  'pre registration price end date help' => {
    'lastUpdated' => '1252528206',
    'message' => 'Fecha a partir de la cual el registro del Evento pasa a tarifa completa.'
  },
  'pre registration price help' => {
    'lastUpdated' => '1252528235',
    'message' => 'El precio especial para este Gafete si el usuario lo adquiere con mucha anticipación.'
  },
  'prereq set name field label' => {
    'lastUpdated' => '1252528307',
    'message' => 'Nombre del Grupo de Requisitos Previos'
  },
  'price' => {
    'lastUpdated' => '1252528322',
    'message' => 'Precio Completo'
  },
  'price help' => {
    'lastUpdated' => '1252528339',
    'message' => 'El precio regular de Registro para este Gafete'
  },
  'price must be greater than zero' => {
    'lastUpdated' => '1252528350',
    'message' => 'El precio debe ser mayor que 0.'
  },
  'print' => {
    'lastUpdated' => '1252528360',
    'message' => 'Imprimir'
  },
  'print badge template' => {
    'lastUpdated' => '1252528378',
    'message' => 'Plantilla para Imprimir Gafete'
  },
  'print badge template help' => {
    'lastUpdated' => '1252528407',
    'message' => 'Seleccione la Plantilla a utilizar para la impresión de los Gafetes.'
  },
  'print remaining ticket template' => {
    'lastUpdated' => '1257424424',
    'message' => 'Plantilla para Imprimir Entradas Restantes'
  },
  'print remaining ticket template help' => {
    'lastUpdated' => '1257424446',
    'message' => 'Seleccione la Plantilla a emplear para desplegar las Entradas restantes.'
  },
  'print remaining tickets' => {
    'lastUpdated' => '1257424459',
    'message' => 'Imprimir Entradas Restantes'
  },
  'print ticket template' => {
    'lastUpdated' => '1252528483',
    'message' => 'Plantilla para Imprimir Entradas'
  },
  'print ticket template help' => {
    'lastUpdated' => '1252528508',
    'message' => 'Seleccione la Plantilla a utilizar para imprimir las Entradas.'
  },
  'printBadgeTemplateId help' => {
    'lastUpdated' => '1252528547',
    'message' => 'El ID de la Plantilla para imprimir el Gafete.'
  },
  'printRemainingTicketsUrl' => {
    'lastUpdated' => '1257424474',
    'message' => 'El URL a la página para imprimir Entradas restantes.'
  },
  'printTicketTemplateId help' => {
    'lastUpdated' => '1252528582',
    'message' => 'El ID de la Plantilla para imprimir la Entrada.'
  },
  'purchase.label' => {
    'lastUpdated' => '1252528688',
    'message' => 'La etiqueta "Agregar al Carrito". Si el Evento está lleno, la variable estará en blanco.'
  },
  'purchase.message' => {
    'lastUpdated' => '1252528873',
    'message' => 'Un mensaje para solicitar al usuario si desea o no mirar los sub Eventos de este Evento. Si el Evento ya está lleno, estará en blanco.'
  },
  'purchase.wantToContinue.url' => {
    'lastUpdated' => '1252528975',
    'message' => 'Un URL para agregar este Evento al Carrito. Si el Evento está lleno, la variable estará en blanco.'
  },
  'purchase.wantToSearch.url' => {
    'lastUpdated' => '1252529168',
    'message' => 'Un URL para buscar Eventos que son requisito para este Evento. Si el Evento está lleno, la variable estará vacía.'
  },
  'purchaseComplete' => {
    'lastUpdated' => '1252529229',
    'message' => 'Un condicional que indica si la compra del Gafete se completó o no.'
  },
  'quantity available' => {
    'lastUpdated' => '1252529283',
    'message' => 'Disponibles'
  },
  'refresh events list' => {
    'lastUpdated' => '1252529347',
    'message' => 'Refrescar Lista de Eventos'
  },
  'refund' => {
    'lastUpdated' => '1252529429',
    'message' => 'Reembolso'
  },
  'registration info message' => {
    'lastUpdated' => '1252529612',
    'message' => 'Ingrese la información de contacto para los Eventos que está agregando a su Carrito.<br><br>Si Ud. ya ingresó al sitio, puede utilizar su Perfil de Usuario para completar la información, de lo contrario seleccione la opción "Crear Mi Gafete".<br><br>Si Ud. está haciendo una compra para otra persona, seleccione su nombre de la lista o la opción "Crear Gafete para otra persona". Si está agregando items a una compra previa, el Gafete ya estará seleccionado y no podrá cambiarlo. Si hace cambios a los campos de este formulario para un Gafete que ya existe, la información será actualizada.'
  },
  'registration staff group' => {
    'lastUpdated' => '1252529690',
    'message' => 'Grupo Staff para Registros'
  },
  'registration staff group help' => {
    'lastUpdated' => '1252529718',
    'message' => 'Seleccione un grupo de usuarios que se harán cargo de los registros. Estos usuarios pueden buscar y gestionar Gafetes para cualquier participante.'
  },
  'registrationStaffGroupId help' => {
    'lastUpdated' => '1252529739',
    'message' => 'El ID del Group encargado de registros.'
  },
  'related badge groups' => {
    'lastUpdated' => '1252529758',
    'message' => 'Grupos relacionados con el Gafete'
  },
  'related badge groups badge help' => {
    'lastUpdated' => '1252529800',
    'message' => 'Verificar los Grupos de Gafetes relacionados con este Gafete, de manera que las Entradas sean asignadas con requisitos previos.'
  },
  'related badge groups ticket help' => {
    'lastUpdated' => '1252529850',
    'message' => 'Indique los Grupos de Gafetes que pueden actuar como requisitos previos antes de poder asistir a este Evento. Si no se indica ninguno, cualquier Gafete puede ser usado.'
  },
  'related ribbons' => {
    'lastUpdated' => '1252529901',
    'message' => 'Cintas Relacionadas'
  },
  'related ribbons help' => {
    'lastUpdated' => '1252529928',
    'message' => 'Marque las Cintas que ofrecen descuentos para esta Entrada.'
  },
  'relatedBadgeGroups' => {
    'lastUpdated' => '1257424495',
    'message' => 'Grupos de Gafetes relacionados con esta Entrada.'
  },
  'relatedRibbons' => {
    'lastUpdated' => '1257424516',
    'message' => 'Bandas relacionadas con esta Entrada.'
  },
  'remove' => {
    'lastUpdated' => '1252529938',
    'message' => 'Eliminar'
  },
  'revisedBy' => {
    'lastUpdated' => '1257424530',
    'message' => 'El ID del usuario que modificó la Entrada por última vez.'
  },
  'revisionDate' => {
    'lastUpdated' => '1257424551',
    'message' => 'La fecha en que la Entrada fue revisada por última vez, como época Unix.'
  },
  'ribbon instructions' => {
    'lastUpdated' => '1252529950',
    'message' => 'Instrucciones para la Cinta'
  },
  'ribbon instructions help' => {
    'lastUpdated' => '1252530163',
    'message' => 'Ofrezca instrucciones al usuario acerca de la manera en que puede aprovechar la Cinta.'
  },
  'ribbonInstructions help' => {
    'lastUpdated' => '1252530180',
    'message' => 'Instrucciones para el usuario acerca de la forma de aprovechar la Cinta.'
  },
  'ribbons' => {
    'lastUpdated' => '1252530185',
    'message' => 'Cintas'
  },
  'schedule back link' => {
    'lastUpdated' => '1252530192',
    'message' => 'Regresar'
  },
  'schedule number of columns' => {
    'lastUpdated' => '1252530217',
    'message' => 'Ubicaciones por Página (columnas)'
  },
  'schedule number of columns help' => {
    'lastUpdated' => '1252530301',
    'message' => 'Esto controla cuántas ubicaciones de Eventos serán presentadas en cada página del programa. Si su evento tiene pocas ubicaciones, entonces utilice ese mismo número aquí; si tiene entre diez y veinte ubicaciones, use la mitad o un tercio de ese número; si tiene muchas más ubicaciones, deje el valor por defecto.'
  },
  'schedule template' => {
    'lastUpdated' => '1252530350',
    'message' => 'Plantilla para el Programa'
  },
  'schedule template help' => {
    'lastUpdated' => '1252530368',
    'message' => 'Seleccione la Plantilla a utilizar para presentar el Programa del Evento.'
  },
  'scheduling conflict continue' => {
    'lastUpdated' => '1252530417',
    'message' => 'Click para continuar'
  },
  'scheduling conflict message' => {
    'lastUpdated' => '1252530452',
    'message' => 'Tiene un conflicto de programación. Elimine de su Carrito alguno de los eventos en conflicto para resolver el conflicto.'
  },
  'search' => {
    'lastUpdated' => '1216073104',
    'message' => 'Buscar'
  },
  'seats available' => {
    'lastUpdated' => '1252530483',
    'message' => 'Asientos Libres'
  },
  'seats available help' => {
    'lastUpdated' => '1252530503',
    'message' => '¿Cuántas personas pueden comprar este item antes de llenar la ubicación?'
  },
  'seatsAvailable' => {
    'lastUpdated' => '1257424600',
    'message' => 'Asientos posibles para esta Entrada.'
  },
  'seatsRemaining' => {
    'lastUpdated' => '1257424592',
    'message' => 'Asientos disponibles para esta Entrada.'
  },
  'select form to edit' => {
    'lastUpdated' => '1259627211',
    'message' => 'Seleccione el Formulario a Editar'
  },
  'select form to submit' => {
    'lastUpdated' => '1259627222',
    'message' => 'Seleccione el Formulario a Enviar'
  },
  'select one' => {
    'lastUpdated' => '1216074714',
    'message' => 'Seleccionar uno'
  },
  'select one or more' => {
    'lastUpdated' => '1252530514',
    'message' => 'Seleccione uno o más'
  },
  'short title' => {
    'lastUpdated' => '1252530521',
    'message' => 'Título'
  },
  'skip' => {
    'lastUpdated' => '1252530534',
    'message' => 'Ignorar'
  },
  'skipNotification' => {
    'lastUpdated' => '1257424625',
    'message' => 'Indica si deben omitirse las notificaciones para esta Entrada.'
  },
  'skipped' => {
    'lastUpdated' => '1252530542',
    'message' => 'ignorado'
  },
  'sku' => {
    'lastUpdated' => '1252530553',
    'message' => 'SKU'
  },
  'sku description' => {
    'lastUpdated' => '1252530583',
    'message' => 'Un número SKU para asignar al Evento. Si se omite, se genera un identificador único global.'
  },
  'sku template' => {
    'lastUpdated' => '1252530591',
    'message' => 'Plantilla para SKU'
  },
  'sku template description' => {
    'lastUpdated' => '1252530683',
    'message' => 'Este campo define como construir el SKU para cada producto. La sintaxis es la misma que para Plantillas normales.'
  },
  'sold out' => {
    'lastUpdated' => '1252530796',
    'message' => 'Agotado'
  },
  'state' => {
    'lastUpdated' => '1252530809',
    'message' => 'Estado o Provincia'
  },
  'status' => {
    'lastUpdated' => '1216073002',
    'message' => 'Estado'
  },
  'submission queue' => {
    'lastUpdated' => '1259627229',
    'message' => 'Cola de Propuestas'
  },
  'submitted location list help' => {
    'lastUpdated' => '1259627266',
    'message' => 'Ingrese una lista de ubicaciones, uno por línea. Esta lista estará disponible en el formulario de Propuesta de Evento, de manera que solamente estas ubicaciones puedan utilizarse.'
  },
  'submitted location list label' => {
    'lastUpdated' => '1259627280',
    'message' => 'Ubicaciones para Eventos Propuestos'
  },
  'switch to badge for' => {
    'lastUpdated' => '1252530824',
    'message' => 'Cambiar al Gafete \'%s\''
  },
  'synopsis' => {
    'lastUpdated' => '1257424639',
    'message' => 'Sinopsis descriptiva de la Entrada.'
  },
  'tagId' => {
    'lastUpdated' => '1257424649',
    'message' => 'TagID para este Activo.'
  },
  'templateId help' => {
    'lastUpdated' => '1252530842',
    'message' => 'El ID de la Plantilla para la página principal del Sistema de Manejo de Eventos.'
  },
  'ticket instructions' => {
    'lastUpdated' => '1252530851',
    'message' => 'Instrucciones para la Entrada'
  },
  'ticket instructions help' => {
    'lastUpdated' => '1252530916',
    'message' => 'Instrucciones para el usuario en cuanto al uso de la Entrada.'
  },
  'ticketDuration' => {
    'lastUpdated' => '1252530930',
    'message' => 'Duración de la Entrada'
  },
  'ticketEventNumber' => {
    'lastUpdated' => '1252530941',
    'message' => 'Número de Evento para la Entrada'
  },
  'ticketInstructions help' => {
    'lastUpdated' => '1252530956',
    'message' => 'Instrucciones para el usuario en cuanto al uso de la Entrada.'
  },
  'ticketLocation' => {
    'lastUpdated' => '1252531026',
    'message' => 'Donde es válida la Entrada.'
  },
  'ticketMeta_[LABEL]' => {
    'lastUpdated' => '1257424742',
    'message' => 'Valor para el campo [LABEL] de metadatos. Los caracteres de [LABEL] que correspondan a espacio en blanco o que no sean alfanuméricos deben reemplazarse por underscores.

Ej: la etiqueta "Primer Nombre" de metadatos debe ser referida como ticketMeta_Primer_Nombre.'
  },
  'ticketStart' => {
    'lastUpdated' => '1252531051',
    'message' => 'Fecha de activación de la Entrada.'
  },
  'ticketTitle' => {
    'lastUpdated' => '1252531064',
    'message' => 'El Título de la Entrada a imprimir.'
  },
  'tickets' => {
    'lastUpdated' => '1252531071',
    'message' => 'Entradas'
  },
  'tickets_loop' => {
    'lastUpdated' => '1257424764',
    'message' => 'Un bucle que itera sobre todos los Tickets restantes y sus datos asociados.'
  },
  'time zone' => {
    'lastUpdated' => '1216073089',
    'message' => 'Zona Horaria'
  },
  'time zone help' => {
    'lastUpdated' => '1252531088',
    'message' => 'Seleccione la Zona Horaria en la cual tendrá lugar el Evento.'
  },
  'timezone help' => {
    'lastUpdated' => '1252531126',
    'message' => 'La zona horaria en la que este Evento está configurado.'
  },
  'title' => {
    'lastUpdated' => '1257424794',
    'message' => 'El título de la Entrada a imprimir.'
  },
  'title.url' => {
    'lastUpdated' => '1252531145',
    'message' => 'Un URL para mostrar la lista de Eventos que contienen a este Evento.'
  },
  'token instructions' => {
    'lastUpdated' => '1252531178',
    'message' => 'Instrucciones para Fichas'
  },
  'token instructions help' => {
    'lastUpdated' => '1252531195',
    'message' => 'Instrucciones para el usuario acerca del uso de las Fichas.'
  },
  'tokenInstructions help' => {
    'lastUpdated' => '1252531245',
    'message' => 'Instrucciones para el usuario en cuanto al uso de las Fichas.'
  },
  'tokens' => {
    'lastUpdated' => '1252531374',
    'message' => 'Fichas'
  },
  'transactionId' => {
    'lastUpdated' => '1252531388',
    'message' => 'El ID de la transacción en la base de datos.'
  },
  'transactionItemId' => {
    'lastUpdated' => '1252531409',
    'message' => 'El ID de la transacción para este Gafete, útil para seguimiento interno.'
  },
  'type label here' => {
    'lastUpdated' => '1252531462',
    'message' => 'Escriba la etiqueta aquí'
  },
  'type name here' => {
    'lastUpdated' => '1252531470',
    'message' => 'Escriba el nombre aquí'
  },
  'url' => {
    'lastUpdated' => '1252531484',
    'message' => 'El URL a este Sistema de Manejo de Eventos.'
  },
  'usePackedHeadTags' => {
    'lastUpdated' => '1257424812',
    'message' => 'Indica si las marcas del encabezado deben compactarse o no para esta Entrada.'
  },
  'user' => {
    'lastUpdated' => '1216073010',
    'message' => 'Usuario'
  },
  'userId' => {
    'lastUpdated' => '1252531500',
    'message' => 'El <strong>userId</strong> del usuario del Gafete.'
  },
  'view badge template' => {
    'lastUpdated' => '1252531513',
    'message' => 'Plantilla para Gafetes'
  },
  'view badge template help' => {
    'lastUpdated' => '1252531540',
    'message' => 'Seleccione la Plantilla a utilizar para desplegar el formulario en el cual el usuario ingresa la información para el Gafete.'
  },
  'view badges' => {
    'lastUpdated' => '1252531574',
    'message' => 'Ver Gafetes'
  },
  'view my submissions' => {
    'lastUpdated' => '1259627290',
    'message' => 'Mis Propuestas'
  },
  'view purchase' => {
    'lastUpdated' => '1252531586',
    'message' => 'Ver Compra'
  },
  'view schedule' => {
    'lastUpdated' => '1252531629',
    'message' => 'Programa'
  },
  'view submission queue' => {
    'lastUpdated' => '1259627324',
    'message' => 'Cola de Propuestas'
  },
  'view tickets' => {
    'lastUpdated' => '1252531637',
    'message' => 'Ver Entradas'
  },
  'viewCartUrl' => {
    'lastUpdated' => '1252531655',
    'message' => 'El URL para llevar al usuario a la pantalla Ver Carrito.'
  },
  'viewEventsUrl' => {
    'lastUpdated' => '1252531666',
    'message' => 'URL para ver Entradas'
  },
  'weight' => {
    'lastUpdated' => '1216073052',
    'message' => 'Peso'
  },
  'weight description' => {
    'lastUpdated' => '1252531701',
    'message' => 'El peso de cualquier cosa que pueda estar asociada con el Evento.'
  },
  'what about duplicates' => {
    'lastUpdated' => '1252531762',
    'message' => '¿Qué hacer con los duplicados?'
  },
  'which badge' => {
    'lastUpdated' => '1252531810',
    'message' => '¿Cuál Gafete?'
  },
  'whichTab' => {
    'lastUpdated' => '1252531843',
    'message' => 'La pestaña actualmente seleccionada en la pantalla de creación de Gafete.'
  },
  'yes' => {
    'lastUpdated' => '1252531887',
    'message' => 'si'
  },
  'you' => {
    'lastUpdated' => '1252531943',
    'message' => 'tu'
  },
  'you do not have any metadata fields to display' => {
    'lastUpdated' => '1252531958',
    'message' => 'No tiene ningún campo de meta datos para mostrar.'
  },
  'zip code' => {
    'lastUpdated' => '1252531967',
    'message' => 'Código Postal'
  },
  'zipcode' => {
    'lastUpdated' => '1252531982',
    'message' => 'El código postal de la dirección en el Gafete.'
  }
}
;

1;
